==> blue2-carnegie-2021-theme-1.0.8-a71306.tar: assets/scripts/people.js <==
const people = () => {
    let dataID;
    let emailData;
    let phoneData;
    let twitterData;
    let descriptionData;
    let titleData;
    let positionData;
    let teamOverlay;
    let email;
    let phone;
    let twitter;
    let description;
    let title;
    let position;

    function getData(obj) {
        dataID = $(obj).data('id');
        emailData = $(obj).data('email');
        phoneData = $(obj).data('phone');
        twitterData = $(obj).data('twitter');
        descriptionData = $(obj).data('description');
        titleData = $(obj).data('title');
        positionData = $(obj).data('position');

        teamOverlay = $('.team-overlay');
        email = teamOverlay.find('.email');
        phone = teamOverlay.find('.phone');
        twitter = teamOverlay.find('.twitter-link');
        description = teamOverlay.find('.description');
        title = teamOverlay.find('.title');
        position = teamOverlay.find('.position');
    }

    function resetFields() {
        email.text('');
        phone.text('');
        twitter.text('');
        description.text('');
        title.text('');
        position.text('');
    }

    function setFields() {
        title.text(titleData);
        description.text(descriptionData);
        position.text(positionData);

        if (emailData) {
            $('.email-holder').show();
            email.text(emailData);
        } else {
            $('.email-holder').hide();
        }

        if (phoneData) {
            $('.phone-holder').show();
            phone.text(phoneData);
        } else {
            $('.phone-holder').hide();
        }

        if (twitterData) {
            twitter.show();
            twitter.attr('href', twitterData);
        } else {
            twitter.hide();
        }
    }

    function setPosition(obj) {
        $('.team-overlay').attr('data-position', obj.data('id'));
    }

    $('.right-control').on('click', function() {
        let currentPos = parseInt(teamOverlay.data('position'), 10);
        currentPos++;
        resetFields();
        if (currentPos > $('.people-read-more').length) {
            currentPos = 1;
        }
        $('.team-overlay').data('position', currentPos);
        getData($(`.people-read-more[data-id="${currentPos}"]`));
        setFields();
    });

    $('.left-control').on('click', function() {
        let currentPos = parseInt(teamOverlay.data('position'), 10);
        currentPos--;
        resetFields();
        if (currentPos <= 0) {
            currentPos = $('.people-read-more').length;
        }
        $('.team-overlay').data('position', currentPos);
        getData($(`.people-read-more[data-id="${currentPos}"]`));
        setFields();
    });

    $('.team-col .cta a').on('click', function(e) {
        e.preventDefault();
        getData($(this));
        resetFields();
        setFields();
        setPosition($(this));
        teamOverlay.addClass('active');
    });

    $('.team-overlay .close').on('click', function() {
        teamOverlay.removeClass('active');
    });
};

export default people;

==> blue2-carnegie-2021-theme-1.0.44-780188.tar: assets/scripts/people.js <==
const people = () => {
    let dataID;
    let emailData;
    let phoneData;
    let twitterData;
    let descriptionData;
    let titleData;
    let positionData;
    let teamOverlay;
    let email;
    let phone;
    let twitter;
    let description;
    let title;
    let position;

    function getData(obj) {
        dataID = $(obj).data('id');
        emailData = $(obj).data('email');
        phoneData = $(obj).data('phone');
        twitterData = $(obj).data('twitter');
        descriptionData = $(obj).data('description');
        titleData = $(obj).data('title');
        positionData = $(obj).data('position');

        teamOverlay = $('.team-overlay');
        email = teamOverlay.find('.email');
        phone = teamOverlay.find('.phone');
        twitter = teamOverlay.find('.twitter-link');
        description = teamOverlay.find('.description');
        title = teamOverlay.find('.title');
        position = teamOverlay.find('.position');
    }

    function resetFields() {
        email.text('');
        phone.text('');
        twitter.text('');
        description.text('');
        title.text('');
        position.text('');
    }

    function setFields() {
        title.text(titleData);
        description.text(descriptionData);
        position.text(positionData);

        if (emailData) {
            const emailHolder = $('.email-holder');
            emailHolder.show();
            email.text(emailData);
            emailHolder.find('a').attr('href', `mailto:${emailData}`);
        } else {
            $('.email-holder').hide();
        }

        if (phoneData) {
            const phoneHolder = $('.phone-holder');
            phoneHolder.show();
            phone.text(phoneData);
            phoneHolder.find('a').attr('href', `tel:${phoneData}`);
        } else {
            $('.phone-holder').hide();
        }

        if (twitterData) {
            twitter.show();
            twitter.attr('href', twitterData);
        } else {
            twitter.hide();
        }
    }

    function setPosition(obj) {
        $('.team-overlay').attr('data-position', obj.data('id'));
    }

    $('.right-control').on('click', function() {
        let currentPos = parseInt(teamOverlay.data('position'), 10);
        currentPos++;
        resetFields();
        if (currentPos > $('.people-read-more').length) {
            currentPos = 1;
        }
        $('.team-overlay').data('position', currentPos);
        getData($(`.people-read-more[data-id="${currentPos}"]`));
        setFields();
    });

    $('.left-control').on('click', function() {
        let currentPos = parseInt(teamOverlay.data('position'), 10);
        currentPos--;
        resetFields();
        if (currentPos <= 0) {
            currentPos = $('.people-read-more').length;
        }
        $('.team-overlay').data('position', currentPos);
        getData($(`.people-read-more[data-id="${currentPos}"]`));
        setFields();
    });

    $('.team-col .cta a').on('click', function(e) {
        e.preventDefault();
        getData($(this));
        resetFields();
        setFields();
        setPosition($(this));
        teamOverlay.addClass('active');
    });

    $('.team-overlay .close').on('click', function() {
        teamOverlay.removeClass('active');
    });
};

export default people;
